@@ -1,5 +1,5 @@
-# GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# GNU Solfege - free ear training software
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@ f#,
 b,,
 >>> print n.get_user_octave_notename()
 b,,
->>> gettext.translation('solfege', '/home/tom/src/solfege/share/locale/', languages=['no_NO']).install()
+>>> gettext.translation('solfege', './share/locale/', languages=['no_NO']).install()
 >>> print n.get_octave_notename()
 b,,
 >>> print n.get_user_octave_notename()
@@ -79,6 +79,7 @@ d'
 if __name__ == "__main__":
     import testsetup
 
+import unittest
 import random
 import _exceptions
 
@@ -203,6 +204,34 @@ class MusicalPitch:
         if self.m_accidental_i == 1 and self.m_notename_i < 6:
             self.m_accidental_i = -1
             self.m_notename_i += 1
+    def normalize_double_accidental(self):
+        """
+        Change the tone so that we avoid double accidentals.
+        """
+        if self.m_accidental_i == 2:
+            if self.m_notename_i in (0, 1, 3, 4, 5): # c d f g a
+                self.m_notename_i += 1
+                self.m_accidental_i = 0
+            elif self.m_notename_i == 2: # e
+                self.m_notename_i = 3
+                self.m_accidental_i = 1
+            else:
+                assert self.m_notename_i == 6 # b
+                self.m_notename_i = 0
+                self.m_accidental_i = 1
+                self.m_octave_i += 1
+        elif self.m_accidental_i == -2:
+            if self.m_notename_i in (1, 2, 4, 5, 6): # d e g a b
+                self.m_notename_i -= 1
+                self.m_accidental_i = 0
+            elif self.m_notename_i == 3: # f
+                self.m_notename_i = 2
+                self.m_accidental_i = -1
+            else:
+                assert self.m_notename_i == 0
+                self.m_notename_i = 6
+                self.m_accidental_i = -1
+                self.m_octave_i -= 1
     def steps(self):
         return self.m_notename_i + self.m_octave_i * 7
     def semitone_pitch(self):
@@ -376,10 +405,36 @@ class MusicalPitch:
             print "Bad translation of notenameformat string"
             return "%(notename)s%(oct)s" % D
 
+class TestMusicalPitch(unittest.TestCase):
+    def test_normalize_double_accidental(self):
+        for a, b in (("c", "c"),
+                     ("cisis", "d"),
+                     ("disis", "e"),
+                     ("eisis", "fis"),
+                     ("fisis", "g"),
+                     ("gisis", "a"),
+                     ("aisis", "b"),
+                     ("bisis", "cis'"),
+                     ("ceses", "bes,"),
+                     ("deses", "c"),
+                     ("eses", "d"),
+                     ("feses", "ees"),
+                     ("geses", "f"),
+                     ("ases", "g"),
+                     ("beses", "a"),
+                     ):
+            n = MusicalPitch.new_from_notename(a)
+            n.normalize_double_accidental()
+            self.assertEquals(n.get_octave_notename(), b)
+
 def _test():
     import doctest
     import musicalpitch
     return doctest.testmod(musicalpitch)
 
+def _test2():
+    unittest.main()
+
 if __name__ == "__main__":
     _test()
+    _test2()
