@@ -1,5 +1,5 @@
-# GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Tom Cato Amundsen
+# GNU Solfege - free ear training software
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007 Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -63,8 +63,13 @@ class MidiFileSynth:
     def _play_track_fork_execl(self, track):
         track.prepend_bpm(60)
         self.create_midifile(track)
-        if not os.path.isfile(self.m_cmd.split()[0]):
-            msg = _("""Failed to play music because the selected midi player program '%s' does not exist. You have to change the sound setup from the preferences window (Ctrl-F12).""") % self.m_cmd.split()[0]
+        err_player = None
+        if not self.m_cmd:
+            err_player = ''
+        elif not os.path.isfile(self.m_cmd.split()[0]):
+            err_player = self.m_cmd.split()[0]
+        if err_player is not None:
+            msg = _("""Failed to play music because the selected midi player program '%s' does not exist. You have to change the sound setup from the preferences window (Ctrl-F12).""") % err_player
             if self.error_report_cb:
                 self.error_report_cb(msg)
             else:
