@@ -1,5 +1,5 @@
-# GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
+# GNU Solfege - free ear training software
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,12 +35,17 @@ class Teacher(abstract.MelodicIntervalTeacher):
         self.m_statistics.enter_test_mode()
         self.m_P.enter_test_mode()
     def get_question(self):
+        """
+        Return a string that can be used to display the intervals.
+        """
         s = self.m_tonika.get_octave_notename()
         last = self.m_tonika
         for i in self.m_question:
             n = mpd.Interval()
             n.set_from_int(i)
             last = last + n
+            if abs(last.m_accidental_i) > 1:
+                last.normalize_double_accidental()
             s = s + " " + last.get_octave_notename()
         return self.m_tonika, r"\staff{ \clef %s %s}" % (mpd.select_clef(s), s)
     def guessed_correct(self):
